==> v6.0.tar.gz: uhr/uhr-de_CH_genau.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_es_isch": {1:[1,2,4,5,6,7]},
	"_genau": {3:[7,8,9,10,11]},
	"_ab": {4:[4,5]},
	"_vor": {4:[1,2,3]},
	"_haubi": {4:[7,8,9,10,11]},
	"_5": {1:[9,10,11]},
	"_10": {2:[9,10,11]},
	"_15": {2:[1,2,3,4,5,6]},
	"_20": {3:[1,2,3,4,5,6]}
};
var layout = {
	"version": 2,
	"language": 'Bärndütsch (genau)',
	"letters": [
		'ESKISCHAFÜF',
		'VIERTUBFZÄÄ',
		'ZWÄNZGGENAU',
		'VORABOHAUBI',
		'EISZWÖISDRÜ',
		'VIERIFÜFIQT',
		'SÄCHSISIBNI',
		'ACHTINÜNIEL',
		'ZÄNIERBEUFI',
		'ZWÖUFINAUHR'
		],
	"permanent": h._es_isch,
	"minutes": {
		"0": h._genau,
		"5,6,7,8,9": [h._5, h._ab],
		"10,11,12,13,14": [h._10, h._ab],
		"15,16,17,18,19": [h._15, h._ab],
		"20,21,22,23,24": [h._20, h._ab],
		"25,26,27,28,29": [h._5, h._vor, h._haubi],
		"30,31,32,33,34": h._haubi,
		"35,36,37,38,39": [h._5, h._ab, h._haubi],
		"40,41,42,43,44": [h._20, h._vor],
		"45,46,47,48,49": [h._15, h._vor],
		"50,51,52,53,54": [h._10, h._vor],
		"55,56,57,58,59": [h._5, h._vor]
	},
	"hours": {
		"1": {5:[1,2,3]},
		"2": {5:[4,5,6,7]},
		"3": {5:[9,10,11]},
		"4": {6:[1,2,3,4,5]},
		"5": {6:[6,7,8,9]},
		"6": {7:[1,2,3,4,5,6]},
		"7": {7:[7,8,9,10,11]},
		"8": {8:[1,2,3,4,5]},
		"9": {8:[6,7,8,9]},
		"10": {9:[1,2,3,4]},
		"11": {9:[8,9,10,11]},
		"12": {10:[1,2,3,4,5,6]}
	}
};
window,_uhr.register('de_CH_genau', layout);

==> v6.2.tar.gz: uhr/uhr-de_CH_genau.js <==
/*
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
var h = {
	"_es_isch": {1:[1,2,4,5,6,7]},
	"_genau": {3:[7,8,9,10,11]},
	"_ab": {4:[4,5]},
	"_vor": {4:[1,2,3]},
	"_haubi": {4:[7,8,9,10,11]},
	"_5": {1:[9,10,11]},
	"_10": {2:[9,10,11]},
	"_15": {2:[1,2,3,4,5,6]},
	"_20": {3:[1,2,3,4,5,6]}
};
var layout = {
	"version": 2,
	"language": 'Bärndütsch (genau)',
	"letters": [
		'ESKISCHAFÜF',
		'VIERTUBFZÄÄ',
		'ZWÄNZGGENAU',
		'VORABOHAUBI',
		'EISZWÖISDRÜ',
		'VIERIFÜFIQT',
		'SÄCHSISIBNI',
		'ACHTINÜNIEL',
		'ZÄNIERBEUFI',
		'ZWÖUFINAUHR'
	],
	"permanent": h._es_isch,
	"minutes": {
		"0": h._genau,
		"5,6,7,8,9": [h._5, h._ab],
		"10,11,12,13,14": [h._10, h._ab],
		"15,16,17,18,19": [h._15, h._ab],
		"20,21,22,23,24": [h._20, h._ab],
		"25,26,27,28,29": [h._5, h._vor, h._haubi],
		"30,31,32,33,34": h._haubi,
		"35,36,37,38,39": [h._5, h._ab, h._haubi],
		"40,41,42,43,44": [h._20, h._vor],
		"45,46,47,48,49": [h._15, h._vor],
		"50,51,52,53,54": [h._10, h._vor],
		"55,56,57,58,59": [h._5, h._vor]
	},
	"hours": {
		"0,12": {10:[1,2,3,4,5,6]},
		"1,13": {5:[1,2,3]},
		"2,14": {5:[4,5,6,7]},
		"3,15": {5:[9,10,11]},
		"4,16": {6:[1,2,3,4,5]},
		"5,17": {6:[6,7,8,9]},
		"6,18": {7:[1,2,3,4,5,6]},
		"7,19": {7:[7,8,9,10,11]},
		"8,20": {8:[1,2,3,4,5]},
		"9,21": {8:[6,7,8,9]},
		"10,22": {9:[1,2,3,4]},
		"11,23": {9:[8,9,10,11]}
	}
};
window,_uhr.register('de_CH_genau', layout);
